<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=sv
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Aktivera insticksmodulen',
	'affichage' => 'Visa',
	'aide_non_disponible' => 'Den här delen av direkthjälpen finns inte i det aktuella språket',
	'auteur' => 'Redaktör',
	'avis_acces_interdit' => 'Tillträde förbjudet.',
	'avis_article_modifie' => 'Varning, @nom_auteur_modif@ har arbetat på den här artikeln för @date_diff@ minuter sen',
	'avis_aucun_resultat' => 'Hittade inga resultat',
	'avis_chemin_invalide_1' => 'Sökvägen du har angett',
	'avis_chemin_invalide_2' => 'är ogiltig. Återgå till den föregående sidan och kontrollera den angivna informationen',
	'avis_connexion_echec_1' => 'Anslutningen till SQL-servern misslyckades.',
	'avis_connexion_echec_2' => 'Återgå till den föregående sidan och kontrollera informationen du angivit.',
	'avis_connexion_echec_3' => '<b>OBS</b> På många servrar måste du  <b>begära</b> aktivering av din databas innan du kan använda den. Om du inte lyckas med uppkopplingen, se till att den är aktiverad.',
	'avis_connexion_ldap_echec_1' => 'Anslutning till LDAP-server misslyckades.',
	'avis_connexion_ldap_echec_2' => 'Återgå till den föregående sidan och kontrollera informationen du angivit.',
	'avis_connexion_ldap_echec_3' => 'Alternativt kan du välja att inte använda LDAP stöd för att importera användare.',
	'avis_deplacement_rubrique' => 'Varning! Den här avdelningen innehåller @contient_breves@ notiser@scb@: om du flyttar den, markera i kryssrutan för att bekräfta.',
	'avis_erreur_connexion_mysql' => 'Fel på SQL-förbindelsen',
	'avis_espace_interdit' => '<b>Förbjudet område</b><p>SPIP är redan installerat.',
	'avis_lecture_noms_bases_1' => 'Installerings-scriptet kunde inte läsa namnen på de installerade databaserna.',
	'avis_lecture_noms_bases_2' => 'Antingen finns det ingen tillgänglig databas eller så är funktionen som listar
 databaser inaktiverad av säkerhetsskäl (det är fallet hos många webbvärdar).',
	'avis_lecture_noms_bases_3' => 'I fråga om det andra alternativet är det möjligt att en databas med ditt användarnamn kan användas:',
	'avis_non_acces_page' => 'Du har inte tillgång till den här sidan.',
	'avis_operation_echec' => 'Operationen misslyckades.',
	'avis_operation_impossible' => 'Operationen omöjlig att genomföra',
	'avis_suppression_base' => 'OBS! Radering av data är permanent och kan inte göras ogjord.',

	// B
	'bouton_acces_ldap' => 'Lägg till en LDAP-katalog >>',
	'bouton_ajouter' => 'Lägg till',
	'bouton_annuler' => 'Avbryt',
	'bouton_demande_publication' => 'Begär att den här artikeln ska publiceras',
	'bouton_desactive_tout' => 'Avaktivera alla',
	'bouton_desinstaller' => 'Avinstallera',
	'bouton_effacer_tout' => 'Radera ALLA',
	'bouton_envoyer_message' => 'Färdigt meddelande: skicka',
	'bouton_modifier' => 'Ändra',
	'bouton_radio_afficher' => 'Visa',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Synas i listan över anslutna redaktörere',
	'bouton_radio_envoi_annonces_adresse' => 'Skicka meddelanden till adressen:',
	'bouton_radio_envoi_liste_nouveautes' => 'Skicka lista över senaste notiser',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Inte synas i listan över anslutna redaktörere',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Skicka inga redaktionella meddelanden',
	'bouton_redirection' => 'OMPEKA',
	'bouton_relancer_installation' => 'Kör installationen igen',
	'bouton_suivant' => 'Nästa',
	'bouton_tenter_recuperation' => 'Försök till reparation',
	'bouton_test_proxy' => 'Testa proxyn',
	'bouton_vider_cache' => 'Töm cachen',

	// C
	'cache_modifiable_webmestre' => 'Den här parametern kan ändras av den webbansvariga.',
	'calendrier_synchro' => 'Om du använder ett kalenderprogram som är kompatibelt med <b>iCal</b> kan du synkronisera det med informationen på den här webbplatsen.',
	'config_activer_champs' => 'Aktivera följande fält',
	'config_choix_base_sup' => 'Ge namnet på en databas på servern',
	'config_erreur_base_sup' => 'SPIP har inte tillgång till de existerande databaserna',
	'config_info_base_sup_disponibles' => 'Ytterligare databaser dit databasfrågor kan skickas:',
	'config_info_logos' => 'Alla objekt på sajten kan kan ha sin egen logotype och dessutom en "mouseover" logotype',
	'config_info_logos_utiliser' => 'Använd logotyper',
	'config_info_logos_utiliser_non' => 'Använd inte logotyper',
	'config_info_logos_utiliser_survol' => 'Använd "mouseover" logotyper',
	'config_info_logos_utiliser_survol_non' => 'Använd inte "mouseover" logotyper',
	'config_info_redirection' => 'Genom att aktivera det här valet kan du skapa virtuella artiklar, som enbart är länkar till artiklar som publicerats på andra sajter oavsett om det är SPIP-sajter eller ej.',
	'config_redirection' => 'Virtuella artiklar',
	'config_titre_base_sup' => 'Konfigurera ytterligare en databas',
	'config_titre_base_sup_choix' => 'Välj ytterligare en databas',
	'connexion_ldap' => 'ldapuppkoppling:',

	// D
	'date_mot_heures' => 'h',

	// E
	'email' => 'e-post',
	'email_2' => 'e-post:',
	'entree_adresse_annuaire' => 'Katalogens adress',
	'entree_adresse_email' => 'Din e-postadress',
	'entree_base_donnee_1' => 'Adress till databasen',
	'entree_base_donnee_2' => '(Ofta är det samma adress som till din webbplats, ibland är det "localhost" och ibland lämnas det helt tomt.)',
	'entree_biographie' => 'Kort biografi med några få ord.',
	'entree_chemin_acces' => '<b>Fyll i</b> sökvägen:',
	'entree_cle_pgp' => 'Din PGP-nyckel',
	'entree_contenu_rubrique' => '(Några få ord som beskriver innehållet i avdelningen)',
	'entree_identifiants_connexion' => 'Dina anslutningsuppgifter',
	'entree_informations_connexion_ldap' => 'Fyll i det här formuläret med uppgifter om din anslutning till LDAP. Din system eller nätverks administratör kan ge dig dessa.',
	'entree_infos_perso' => 'Vem är du?',
	'entree_interieur_rubrique' => 'I avdelning:',
	'entree_liens_sites' => '<b>Hyperlänk</b> (referens, sajt att besöka...)',
	'entree_login' => 'Dina användaruppgifter',
	'entree_login_connexion_1' => 'Användarupgifter för anslutningen',
	'entree_login_connexion_2' => '(Är ibland samma som lösenordet för FTP-åtkomst och ibland kan det lämnas tomt)',
	'entree_mot_passe' => 'Ditt lösenord',
	'entree_mot_passe_1' => 'Lösenord för anslutningen',
	'entree_mot_passe_2' => '(Är ibland samma som lösenordet för FTP-åtkomst och ibland kan det lämnas tomt)',
	'entree_nom_fichier' => 'Skriv in filnamnet @texte_compresse@',
	'entree_nom_pseudo' => 'Ditt namn eller alias',
	'entree_nom_pseudo_1' => '(Ditt namn eller alias)',
	'entree_nom_site' => 'Din webbplats namn',
	'entree_nouveau_passe' => 'Nytt lösenord',
	'entree_passe_ldap' => 'Lösenord',
	'entree_port_annuaire' => 'Katalogens portnummer',
	'entree_signature' => 'Signatur',
	'entree_titre_obligatoire' => '<b>Title</b> [Krävs]<br />',
	'entree_url' => 'Din webbplats URL',
	'erreur_plugin_fichier_absent' => 'Filen saknas',
	'erreur_plugin_fichier_def_absent' => 'Definitionsfilen saknas',
	'erreur_plugin_nom_fonction_interdit' => 'Förbjudet namn för funktionen',
	'erreur_plugin_nom_manquant' => 'plugin-namnet saknas',
	'erreur_plugin_prefix_manquant' => 'Pluginens prefix odefinierad',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; saknas i definitionsfilen',
	'erreur_plugin_version_manquant' => 'Denna plugin saknar version.',

	// I
	'ical_info1' => 'Denna sida visar flera metoder att hålla dig informerad om aktiviteter på sajten.',
	'ical_info2' => 'För mer information, tveka inte om att besöka <a href="@spipnet@">SPIP’s dokumentation</a>.', # MODIF
	'ical_info_calendrier' => 'Du kan använda två kalendrar. En är en sajtkarta med alla publicerade artiklar. Den andra innehåller redaktionella meddelanden och dina senaste privata meddelanden: Den är personlig, tack vare en genererad nyckel som du kan förändra när som helst genom att byta lösenord.',
	'ical_methode_http' => 'Nerladdning',
	'ical_methode_webcal' => 'Synkronisering (webcal://)', # MODIF
	'ical_texte_js' => 'En rad javascript tillåter dig att, väldigt enkelt och på vilken sajt du vill, visa en lista på de senaste artiklarna publicerade på den här sajten.',
	'ical_texte_prive' => 'Den här kalendern som är personlig, innnehåller dina egna redaktionella händelser på den här sajten (uppgifter, egna möten, inlämnade artiklar och nyheter...).',
	'ical_texte_public' => 'Den här kalendern låter dig följa den publika aktiviteten på sajten (publicerade artiklar och nyheter).',
	'ical_texte_rss' => 'Du kan syndikerar de senaste nyheterna på den är sajten i vilken XML/RSS-läsare som helst. Det är samma format som gör det möjligt att läsa de senaste nyheterna på andra sajter som använder ett kompatibelt format. (syndikerade sajter).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'E-postlista',
	'ical_titre_rss' => 'Syndikeringsfiler',
	'icone_activer_cookie' => 'Sätt en cookie',
	'icone_admin_plugin' => 'Hantera plugin’s',
	'icone_afficher_auteurs' => 'Visa redaktörer',
	'icone_afficher_visiteurs' => 'Visa besökare',
	'icone_arret_discussion' => 'Avsluta diskussionen',
	'icone_calendrier' => 'Kalender',
	'icone_creer_auteur' => 'Skapa en ny redaktör och koppla honom (henne) till den här artikeln',
	'icone_creer_mot_cle' => 'Skapa ett nytt nyckelord och länka det till artikeln',
	'icone_creer_rubrique_2' => 'Skapa en ny avdelning',
	'icone_modifier_article' => 'Editera artikeln',
	'icone_modifier_rubrique' => 'Editera avdelningen',
	'icone_relancer_signataire' => 'Kontakta personen igen',
	'icone_retour' => 'Tillbaka',
	'icone_retour_article' => 'Tillbaka till artikeln',
	'icone_supprimer_cookie' => 'Radera cookien',
	'icone_supprimer_rubrique' => 'Radera den här avdelningen',
	'icone_supprimer_signature' => 'Radera den här signaturen',
	'icone_valider_signature' => 'Validera signaturen',
	'image_administrer_rubrique' => 'Du kan hantera den här avdelningen',
	'info_1_article' => '1 artikel',
	'info_activer_cookie' => 'Du kan aktivera en <b>administrationscookie</b>, som tillåter dig
 att enkelt växla mellan den publika och den privata delen.',
	'info_administrateur' => 'Administratör',
	'info_administrateur_1' => 'Administratör',
	'info_administrateur_2' => 'på sajten (<i>använd med försiktighet</i>)',
	'info_administrateur_site_01' => 'Om du är en sajt-administratör, var vänlig',
	'info_administrateur_site_02' => 'klicka på den här länken',
	'info_administrateurs' => 'Administratörer',
	'info_administrer_rubrique' => 'Du kan hantera den här avdelningen',
	'info_adresse' => 'till adressen:',
	'info_adresse_url' => 'Din sajts publika URL',
	'info_aide_en_ligne' => 'SPIP Online Hjälp',
	'info_ajout_image' => 'När du lägget till filer som bifogade dokument till en artikel,
  kan SPIP automatiskt skapa miniatyrer av de
  inlagda bilderna. Det tillåter till exempel
  att man automatiskt skapar ett galleri eller en portfolio.',
	'info_ajouter_rubrique' => 'lägg till en annan avdelning:',
	'info_annonce_nouveautes' => 'Senaste nyheterna',
	'info_article' => 'artikel',
	'info_article_2' => 'artiklar',
	'info_article_a_paraitre' => 'Fördaterade artiklar som kommer att publiceras',
	'info_articles_02' => 'artiklar',
	'info_articles_2' => 'Artiklar',
	'info_articles_auteur' => 'Den här redaktörens artiklar',
	'info_articles_trouves' => 'Artiklar hittade',
	'info_attente_validation' => 'Dina artiklar som väntar på validering',
	'info_aujourdhui' => 'idag:',
	'info_auteurs' => 'Redaktörer',
	'info_auteurs_par_tri' => 'Redaktörer@partri@',
	'info_auteurs_trouves' => 'Redaktörer funna',
	'info_authentification_externe' => 'Extern autentifiering',
	'info_avertissement' => 'Varning',
	'info_barre_outils' => 'med dess verktygsfält?',
	'info_base_installee' => 'Databasen är skapad',
	'info_chapeau' => 'Ingress',
	'info_chapeau_2' => 'Introduktion:',
	'info_chemin_acces_1' => 'inställningar: <b>sökväg i katalogen</b>',
	'info_chemin_acces_2' => 'Från och med nu måste du konfigurera sökvägen till katalogen information. Det är nödvändigt för att kunna läsa användarprofilerna som är sparade i katalogen.',
	'info_chemin_acces_annuaire' => 'Inställningar: <b>Sökväg i katalogen</b>',
	'info_choix_base' => 'Tredje steget:',
	'info_code_acces' => 'Glöm inte ditt eget lösenord!',
	'info_config_suivi' => 'Om den här adressen är en mailing lista, kan du under adressen visa var man kan registrera sig. Det kan vara en URL (till exempel en webbsida där man kan registrera sig), eller en e-postadress med en speciell ärenderad (till exempel: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Du kan anmäla dig till sajtens nyhetsbrev. Du kommer då att automatiskt få meddelanden om artiklar och nyheter som laddats upp för publicering.',
	'info_confirmer_passe' => 'Bekräfta ditt nya lösenord:',
	'info_connexion_base' => 'Försöker att ansluta till databasen',
	'info_connexion_ldap_ok' => 'Din förbindelse till LDAP-servern lyckades.</b><p> Du kan gå vidare till nästa steg.</p>', # MODIF
	'info_connexion_mysql' => 'Din databasförbindelse',
	'info_connexion_ok' => 'Förbindelsen lyckades.',
	'info_contact' => 'Kontakt',
	'info_contenu_articles' => 'Innehåll i artiklarna',
	'info_creation_paragraphe' => '(För att skapa stycken, räcker det att lämna tomma rader.)', # MODIF
	'info_creation_rubrique' => 'Innan du kan skriva artiklar,<br /> måste du skapa åtminstone en avdelning.<br />',
	'info_creation_tables' => 'Skapar databastabeller',
	'info_creer_base' => '<b>Skapa</b> en ny databas:',
	'info_dans_rubrique' => 'I avdelningen:',
	'info_date_publication_anterieure' => 'Datum för tidigare publicering:',
	'info_date_referencement' => 'DATUM DÅ SAJTEN LÄNKADES:',
	'info_derniere_etape' => 'Klart!',
	'info_descriptif' => 'Beskrivning:',
	'info_desinstaller_plugin' => 'raderar data och avaktiverar tillägget',
	'info_discussion_cours' => 'Pågående diskussion',
	'info_ecrire_article' => 'Innan du kan skriva artiklar, ymåste du skapa minst en avdelning.',
	'info_email_envoi' => 'Avsändaren mailadress (frivilligt)',
	'info_email_envoi_txt' => 'Skriv in avsändarens e-postadress som används när man sänder mejlen (som default används mottagarens adress som avsändaradress) :',
	'info_email_webmestre' => 'Webmasterns mejladress (frivillig)', # MODIF
	'info_envoi_email_automatique' => 'Automatisk e-post',
	'info_envoyer_maintenant' => 'Skicka nu',
	'info_etape_suivante' => 'Gå till nästa steg',
	'info_etape_suivante_1' => 'Du kan fortsätta till nästa steg.',
	'info_etape_suivante_2' => 'Du kan fortsätta till nästa steg.',
	'info_exportation_base' => 'Exportera databasen till @archive@',
	'info_facilite_suivi_activite' => 'För att underlätta att följa de redaktionella;
  aktiviteterna, kan SPIP skicka medddelanden via e-post, exempelvis till en maillista för redaktörer,
  angående publiceringar och godkännanden.',
	'info_fichiers_authent' => 'Lösenordsfil ".htpasswd"',
	'info_gauche_auteurs' => 'Här hittar du alla redaktörer på sajten.
 Status på var och en av dem visas av färgen på ikonen (administratör = grön; redaktör = gul).',
	'info_gauche_auteurs_exterieurs' => 'Externa redaktörer utan behörighet på sajten, visas med en blå ikon; raderade redaktörer med en soptunna.', # MODIF
	'info_generation_miniatures_images' => 'Skapande av tumnagelbilder.',
	'info_hebergeur_desactiver_envoi_email' => 'Vissa webhotell avaktiverar automatisk mejl
på deras servrar. Om så är fallet kan följande
funktioner hos SPIP inte användas.',
	'info_hier' => 'I går:',
	'info_identification_publique' => 'Din publika identitet...',
	'info_image_process' => 'Välj den bästa metoden för att skapa miniatyrer genom att klicka på motsvarande bild.',
	'info_image_process2' => '<b>OBS!.</b> <i>Om du inte kan se någon bild, så är din server inte konfigurerad för att använda sådana verktyg. Om du vill använda dessa finesser så kontakta din leverantörs tekniska support och be dem installera utökningarna för «GD» eller «Imagick».</i>', # MODIF
	'info_informations_personnelles' => 'Personlig information',
	'info_inscription_automatique' => 'Automatisk registreing av nya redaktörer',
	'info_jeu_caractere' => 'Sajtens teckenuppsättning',
	'info_jours' => 'dagar',
	'info_laisser_champs_vides' => 'Lämna dessa fält tomma)',
	'info_langues' => 'Sajtens språk',
	'info_lien_hypertexte' => 'Hyperlänk:',
	'info_liste_redacteurs_connectes' => 'Inlogggade redaktörer',
	'info_login_existant' => 'Användarnamnet finns redan.',
	'info_login_trop_court' => 'Användarnamnet är för kort.',
	'info_logos' => 'Logotyperna',
	'info_maximum' => 'maximum:',
	'info_meme_rubrique' => 'I samma avdelning',
	'info_message_en_redaction' => 'utkorg',
	'info_message_technique' => 'Tekniskt meddelande:',
	'info_messagerie_interne' => 'Internmeddelande',
	'info_mise_a_niveau_base' => 'SQL database upgradering',
	'info_mise_a_niveau_base_2' => '{{Warning!}} Du har installerat {äldre} 
  SPIP filer än de som redan
  varit installerade på sajten: Du riskerar att förlora databasen
  och ha en sajt som inte längre fungerar.<br />{{återinstallera
  SPIP filerna.}}',
	'info_modifier_auteur' => 'Editera detaljer för redaktören:',
	'info_modifier_rubrique' => 'Editera avdelningen:',
	'info_modifier_titre' => 'Editera: @titre@',
	'info_mon_site_spip' => 'Min SPIP-sajt',
	'info_moyenne' => 'genomsnitt:',
	'info_multi_cet_article' => 'Den här artikelns språk:',
	'info_multi_langues_choisies' => 'Var vänlig, välj tillgängliga språk för redaktörerna bland språken nedan.
  Språk som redan används på din sajt (högst upp på listan) kan inte avaktiveras.',
	'info_multi_secteurs' => '... bara för avdelningarna i roten?',
	'info_nom' => 'Namn',
	'info_nom_destinataire' => 'Mottagarens namn',
	'info_nom_site' => 'Din sajts namn',
	'info_nombre_articles' => '@nb_articles@ artiklar,',
	'info_nombre_rubriques' => '@nb_rubriques@ avdelningar,',
	'info_nombre_sites' => '@nb_sites@ sajter,',
	'info_non_deplacer' => 'Flytta inte...',
	'info_non_envoi_liste_nouveautes' => 'Skicka inte listan med senaste nyheterna',
	'info_non_modifiable' => 'kan inte förändras',
	'info_non_suppression_mot_cle' => 'Jag vill inte radera nyckelordet.',
	'info_notes' => 'Fotnoter',
	'info_nouvel_article' => 'Ny artikel',
	'info_nouvelle_traduction' => 'Ny översättning:',
	'info_numero_article' => 'ARTIKEL NUMMER:',
	'info_obligatoire_02' => '[Krävs]', # MODIF
	'info_option_accepter_visiteurs' => 'Tillåt besökare registrera sig på den publika delen',
	'info_option_ne_pas_accepter_visiteurs' => 'Avvisa besökarregistrering',
	'info_options_avancees' => 'AVANCERADE INSTÄLLNINGAR',
	'info_ou' => 'eller...',
	'info_page_interdite' => 'Förbjuden sida',
	'info_par_nom' => 'efter namn',
	'info_par_nombre_article' => 'efter antal artiklar',
	'info_par_statut' => 'efter status',
	'info_par_tri' => '’(efter @tri@)’',
	'info_passe_trop_court' => 'lösenordet är för kort.',
	'info_passes_identiques' => 'De två lösenorden är inte identiska.',
	'info_plus_cinq_car' => 'mer än 5 tecken',
	'info_plus_cinq_car_2' => '(Mer än 5 tecken)',
	'info_plus_trois_car' => '(Mer än 3 tecken)',
	'info_popularite' => 'popularitet: @popularite@; besök: @visites@',
	'info_post_scriptum' => 'Postscript',
	'info_post_scriptum_2' => 'PS:',
	'info_pour' => 'för',
	'info_procedez_par_etape' => 'Var vänlig, fortsätt steg för steg',
	'info_procedure_maj_version' => 'Uppdateringsproceduren skall köras för att
 anpassa databasen till den nya versionen av SPIP.',
	'info_proxy_ok' => 'Testen av proxy lyckades.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publicera',
	'info_publies' => 'Dina onlinepublicerade artiklar',
	'info_question_accepter_visiteurs' => 'Om sajtens template tillåter besökare att registrera sig utan att gå in i den privata delen, var vänlig och aktivera följande option:',
	'info_racine_site' => 'Sajtens bas',
	'info_recharger_page' => 'Var vänlig och uppdatera sidan om en liten stund.',
	'info_recherche_auteur_zero' => 'Inga resultat hittades för "@cherche_auteur@".',
	'info_recommencer' => 'Var vänlig och försök igen.',
	'info_redacteur_1' => 'Redaktör',
	'info_redacteur_2' => 'för tillgång till den privata delen (<i>rekommenderas</i>)',
	'info_redacteurs' => 'Redaktörer',
	'info_redaction_en_cours' => 'UNDER ARBETE',
	'info_redirection' => 'Ompekning',
	'info_refuses' => 'Refuserade artiklar',
	'info_reglage_ldap' => 'inställningar: <b>anpassar LDAP import</b>',
	'info_renvoi_article' => '<b>Ompekning.</b> Den här artikeln pekar om till:',
	'info_reserve_admin' => 'Enbart administratörer kan förändra adressen.',
	'info_restreindre_rubrique' => 'Begränsa administrationen till avdelningen:',
	'info_resultat_recherche' => 'Sökresultat:',
	'info_rubriques' => 'Avdelningar',
	'info_rubriques_02' => 'avdelningar',
	'info_rubriques_trouvees' => 'Hittade avdelningar',
	'info_sans_titre' => 'Utan titel',
	'info_selection_chemin_acces' => '<b>Välj</b> åtkomstväg i katalogen:',
	'info_signatures' => 'underskrifter',
	'info_site' => 'Sajt',
	'info_site_2' => 'sajt:',
	'info_site_min' => 'sajt',
	'info_site_reference_2' => 'Länkad sajt',
	'info_site_web' => 'WEBBSAJT:', # MODIF
	'info_sites' => 'sajter',
	'info_sites_lies_mot' => 'Länkade sajter knutna till detta nyckelord',
	'info_sites_proxy' => 'Använder en proxy',
	'info_sites_trouves' => 'Hittade sajter',
	'info_sous_titre' => 'Undertitel:',
	'info_statut_administrateur' => 'Administratör',
	'info_statut_auteur' => 'Redaktörens status:', # MODIF
	'info_statut_auteur_a_confirmer' => 'Registreringar som skall godkännas',
	'info_statut_auteur_autre' => 'Annan status:',
	'info_statut_redacteur' => 'Redaktör',
	'info_statut_utilisateurs_1' => 'Startinställningar för importerade användare',
	'info_suivi_activite' => 'Följ upp aktiviteten på sajten',
	'info_surtitre' => 'Övertitel:',
	'info_syndication_integrale_1' => 'Din sajt publiceras RSS-filer för syndikering (Se <a href="@url@">@titre@</a>).',
	'info_syndication_integrale_2' => 'Vill du skicka hela artiklar eller bara en sammanfattning på ett par hundra tecken?',
	'info_table_prefix' => 'Det är möjligt att byta prefix i databastabellernas namn. (Du behöver göra det om di installerar flera sajter i samma databas). Prefixet måste skrivas utan accenter, med versaler utan mellanslag.',
	'info_taille_maximale_vignette' => 'Maximal storlek på miniatyrer som skapats av systemet:',
	'info_terminer_installation' => 'Du kan nu avsluta installationsprocessen.',
	'info_texte' => 'Text',
	'info_texte_explicatif' => 'Förklarande text',
	'info_texte_long' => '(Texten är lång: Den kommer att synas i flera delar som sedan sammanfogas efter validering.)',
	'info_texte_message' => 'Texten i ditt meddelande:', # MODIF
	'info_texte_message_02' => 'Texten i ditt meddelande',
	'info_titre' => 'Titel:',
	'info_total' => 'total:',
	'info_tous_articles_en_redaction' => 'Alla artiklar under arbete',
	'info_tous_articles_presents' => 'Alla artiklar som publicerats i den här avdelningen',
	'info_tous_les' => 'alla:',
	'info_tout_site' => 'Hela sajten',
	'info_tout_site2' => 'Artikeln har inte blivit översatt till det här språket.',
	'info_tout_site3' => 'Artikeln har blivit översatt till det hör språket men vissa förändringar har gjorts senare i orginalartikeln. Översättningen behöver uppdateras.',
	'info_tout_site4' => 'Artikeln har blivit översatt till det här språket och översättningen är aktuell.',
	'info_tout_site5' => 'Orginalartikeln.',
	'info_tout_site6' => '<b>OBS:</b> bara orginalartiklarna visas.
Översättningarna är länkade till orginalet
med en färg som visar deras status:',
	'info_travail_colaboratif' => 'Gemensamt arbete på artiklar',
	'info_un_article' => 'en artikel,',
	'info_un_site' => 'En sajt,',
	'info_une_rubrique' => 'en avdelning,',
	'info_une_rubrique_02' => '1 avdelning',
	'info_url' => 'URL:',
	'info_urlref' => 'Hyperlänk:',
	'info_utilisation_spip' => 'SPIP är nu färdig att användas..',
	'info_visites_par_mois' => 'Besökare per månad:',
	'info_visiteur_1' => 'Besökare',
	'info_visiteur_2' => 'på den publika delen',
	'info_visiteurs' => 'Besökare',
	'info_visiteurs_02' => 'Beökare på den publika delen',
	'install_adresse_base_hebergeur' => 'Databasadress tillhandahållen av webbhotellet',
	'install_echec_annonce' => 'Den här installationen kommer förmodligen inte att fungera, alternativt resulterar den i en sajt med reducerad funktionalitet ...',
	'install_extension_mbstring' => 'SPIP fungerar inte med:',
	'install_extension_php_obligatoire' => 'SPIP kräver ett tillägg till php:',
	'install_login_base_hebergeur' => 'Login tilldelat av leverantören',
	'install_nom_base_hebergeur' => 'Databasnamn tilldelat av leverantören:',
	'install_pas_table' => 'Databasen har inga tabeller',
	'install_pass_base_hebergeur' => 'Lösenord till databasen tilldelat av leverantören',
	'install_php_version' => 'Versionen av PHP, @version@ är för gammal (minimum = @minimum@)',
	'install_select_langue' => 'Välj ett språk, klicka sedan på knappen "fortsätt" för att starta installationen.',
	'install_select_type_db' => 'Välj typ av databas :',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_tables_base' => 'Databasens tabeller',
	'intem_redacteur' => 'redaktör',
	'intitule_licence' => 'Licens',
	'item_accepter_inscriptions' => 'Tillåt registreringar',
	'item_activer_messages_avertissement' => 'Aktivera varningsmeddelanden',
	'item_administrateur_2' => 'administratör',
	'item_afficher_calendrier' => 'Visa i kalendern',
	'item_autoriser_syndication_integrale' => 'Inkludera hela artiklar i syndikeringsfilerna',
	'item_choix_administrateurs' => 'administratörer',
	'item_choix_generation_miniature' => 'Generera miniatyrer automatiskt.',
	'item_choix_non_generation_miniature' => 'Generera inte miniatyrer.',
	'item_choix_redacteurs' => 'redaktörer',
	'item_choix_visiteurs' => 'besökare till den publika delen',
	'item_creer_fichiers_authent' => 'Skapa .htpasswd filer',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Aktivera meddelandesystemet och kalendern',
	'item_mots_cles_association_articles' => 'artiklar',
	'item_mots_cles_association_rubriques' => 'avdelningar',
	'item_mots_cles_association_sites' => 'länkade eller syndikerade sajter.',
	'item_non' => 'Nej',
	'item_non_accepter_inscriptions' => 'Tillåt inte registreringar',
	'item_non_activer_messages_avertissement' => 'Inga varningsmeddelanden',
	'item_non_afficher_calendrier' => 'Visa inte i kalendern',
	'item_non_autoriser_syndication_integrale' => 'Skicka bara en sammanfattning',
	'item_non_creer_fichiers_authent' => 'Skapa inte dessa filer',
	'item_non_messagerie_agenda' => 'Avaktivera meddelandesystemet och kalendern',
	'item_non_publier_articles' => 'Publicera inte artiklar innan deras publiceringsdatum.',
	'item_nouvel_auteur' => 'Ny redaktör',
	'item_nouvelle_rubrique' => 'Ny avdelning',
	'item_oui' => 'Ja',
	'item_publier_articles' => 'Publicera artiklarna utan att ta hänsyn till publiceringsdatum.',
	'item_reponse_article' => 'Svara på artikeln',
	'item_visiteur' => 'besökare',

	// J
	'jour_non_connu_nc' => 'okänd',

	// L
	'lien_ajouter_auteur' => 'Lätt till redaktören',
	'lien_email' => 'e-post',
	'lien_nom_site' => 'SAJTENS NAMN:',
	'lien_retirer_auteur' => 'Ta bort redaktören',
	'lien_site' => 'sajt',
	'lien_tout_deplier' => 'Expandera alla',
	'lien_tout_replier' => 'Kollapsa alla',
	'lien_tout_supprimer' => 'Radera alla',
	'lien_trier_nom' => 'Sortera efter namn',
	'lien_trier_nombre_articles' => 'Sortera efter artikelnummer',
	'lien_trier_statut' => 'Sortera efter status',
	'lien_voir_en_ligne' => 'SE ONLINE:',
	'logo_article' => 'ARTIKELNS LOGOTYPE', # MODIF
	'logo_auteur' => 'REDAKTÖRENS LOGOTYPE', # MODIF
	'logo_rubrique' => 'Avdelningens logotype', # MODIF
	'logo_site' => 'SAJTENS LOGOTYPE', # MODIF
	'logo_standard_rubrique' => 'STANDARDLOGOTYPE FÖR AVDELNINGAR', # MODIF
	'logo_survol' => 'LOGOTYPE FÖR MUS-ÖVER', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Välj din databas',
	'module_fichier_langue' => 'Språkfiler',
	'module_raccourci' => 'Genväg',
	'module_texte_affiche' => 'Visad text',
	'module_texte_traduction' => 'Språkfilen « @module@ » finns i:',

	// O
	'onglet_contenu' => 'Innehåll',
	'onglet_declarer_une_autre_base' => 'Ange en annan databas',
	'onglet_discuter' => 'Diskutera',
	'onglet_interactivite' => 'Interaktivitet',
	'onglet_proprietes' => 'Egenskaper',
	'onglet_repartition_actuelle' => 'nu',

	// P
	'plugin_etat_developpement' => 'Under utveckling',
	'plugin_etat_experimental' => 'exprimentell',
	'plugin_etat_stable' => 'Stabil',
	'plugin_etat_test' => 'under test',
	'plugin_impossible_activer' => 'Omöjligt att aktivera pluginen @plugin@',
	'plugin_necessite_plugin' => 'Version @version@ eller nyare av pluginen @plugin@ krävs.', # MODIF
	'plugin_zip_active' => 'Fortsätt för att aktivera',
	'plugin_zip_installe_finie' => 'Filen @zip@ har packats upp och installerats.',
	'plugin_zip_installe_rep_finie' => 'Filen @zip@ har packats upp och installerats i katalogen @rep@',
	'plugin_zip_installer' => 'Du kan installera nu.',
	'plugins_actifs' => '@count@ aktiva plugins.',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponibles' => '@count@ tillgängliga plugins.',
	'plugins_erreur' => 'Fel i följande plugin: @plugins@',
	'plugins_liste' => 'Lista över plugins',

	// R
	'required' => '[Krävs]', # MODIF

	// T
	'taille_cache_vide' => 'Cachen är tom.',
	'text_article_propose_publication' => 'Artikel inlämnad för publicering. tveka inte att säga din mening i forumet längst ned på sidan.', # MODIF
	'texte_admin_effacer_01' => 'Detta kommando raderar <i>all</i> information i databasen,
inklusive <i>alla</i> uppgifter om användare. Efter att du använt det, måste du 
installera om SPIP för att skapa en ny databas och den första administratören.',
	'texte_adresse_annuaire_1' => '( Om din katalog är installerad på samma dator som din websajt, är det troligen «localhost».)',
	'texte_ajout_auteur' => 'Följande redaktör lades till artikeln:',
	'texte_annuaire_ldap_1' => 'Om du har tillgång till en LDAP-katalog kan du använda den för att importera användare till SPIP.',
	'texte_article_statut' => 'Artikelns status:',
	'texte_article_virtuel' => 'Virtuell artikel',
	'texte_article_virtuel_reference' => '<b>Virtuell Artikel:</b> länkad artikel i din SPIP site, men ompekad till en annan URL. För att ta bort ompekningen, radera denna URL.',
	'texte_aucun_resultat_auteur' => 'Inga resultat för "@cherche_auteur@".',
	'texte_auteurs' => 'REDAKTÖRERNA',
	'texte_choix_base_1' => 'Välj din databas:',
	'texte_choix_base_2' => 'Databasservern innehåller flera databaser.',
	'texte_choix_base_3' => '<b>Välj</b> den som din leverantör har gett dig:',
	'texte_choix_table_prefix' => 'Prefix för tabeller:',
	'texte_compte_element' => '@count@ objekt',
	'texte_compte_elements' => '@count@ element',
	'texte_jeu_caractere_3' => 'Din sajt använder följande teckenuppsättning:',
	'texte_mise_a_niveau_base_1' => 'Du har just uppdaterat filerna i SPIP.
 Nu måste du uppgradera sajtens databas.',
	'texte_modifier_article' => 'Redigera artikeln:',
	'texte_multilinguisme' => 'Om du vill hantera artiklar på flera språk, med en avancerad navigering, kan du lägga till en option för språkval i artiklar och avdelningar, i enlighet med sajtens struktur.', # MODIF
	'texte_multilinguisme_trad' => 'Dessutom kan du aktivera ett system för länkhantering av de olika översättningarna av en artikel.', # MODIF
	'texte_non_compresse' => '<i>okomprimerad</i> (din server stöder inte denna funktion)',
	'texte_nouvelle_version_spip_1' => 'Du har installerat en ny version av SPIP.',
	'texte_plus_trois_car' => 'mer än tre tecken',
	'texte_plusieurs_articles' => 'Flera redaktörer hittades för  "@cherche_auteur@":',
	'texte_recalcul_page' => 'Om du vill uppdatera
enbart en sida, är det bäst att göra det från den publika delen genom att klicka på « Ladda om sidan ».',
	'texte_recuperer_base' => 'Reparera databasen',
	'texte_sous_titre' => 'Undertitel',
	'texte_statistiques_visites' => '(mörka staplar:  Söndag / mörk linje: genomsnittlig nivå)',
	'texte_statut_attente_validation' => 'väntar på godkännande',
	'texte_statut_publies' => 'publicerad online',
	'texte_statut_refuses' => 'avvisad',
	'texte_suppression_fichiers' => 'Använd detta kommando för att radera alla filer
i SPIP’s cache. Det gör det möjligt att tvinga fram en uppdatering av alla sidor om du
gjort viktiga förändringar i sajtens utseende eller struktur.',
	'texte_sur_titre' => 'Övertitel',
	'texte_table_ok' => ': den här tabellen är OK.',
	'texte_tentative_recuperation' => 'Reparationsförsök',
	'texte_tenter_reparation' => 'Försök att reparera databasen',
	'texte_titre_02' => 'Ärenderad:',
	'texte_titre_obligatoire' => '<b>Titel</b> [Krävs]',
	'texte_travail_article' => '@nom_auteur_modif@ arbetade med den här artikeln för @date_diff@ minuter sedan',
	'texte_vide' => 'tom',
	'texte_vider_cache' => 'töm cachen',
	'titre_admin_tech' => 'Tekniskt underhåll',
	'titre_admin_vider' => 'Tekniskt underhåll',
	'titre_cadre_afficher_article' => 'Visa artiklarna:',
	'titre_cadre_afficher_traductions' => 'Visa status för översättningen för följande språk:',
	'titre_cadre_ajouter_auteur' => 'LÄGG TILL EN REDAKTÖR:',
	'titre_cadre_interieur_rubrique' => 'I Avdelningen',
	'titre_cadre_numero_auteur' => 'Redaktör nummer',
	'titre_cadre_signature_obligatoire' => '<b>Signatur</b> [krävs]<br />',
	'titre_config_fonctions' => 'Sajtens konfiguration',
	'titre_configuration' => 'Sajtens konfiguration',
	'titre_connexion_ldap' => 'Optioner: <b>Din LDAP koppling</b>',
	'titre_groupe_mots' => 'NYCKELORDSGRUPP:',
	'titre_langue_article' => 'ARTIKELNS SPRÅK', # MODIF
	'titre_langue_rubrique' => 'AVDELNINGENS SPRÅK', # MODIF
	'titre_langue_trad_article' => 'ARTIKESPRÅK OCH ÖVERSÄTTNINGAR',
	'titre_les_articles' => 'ARTIKLAR',
	'titre_naviguer_dans_le_site' => 'Navigera i sajten...',
	'titre_nouvelle_rubrique' => 'Ny avdelning',
	'titre_numero_rubrique' => 'AVDELNING NUMMER:',
	'titre_page_articles_edit' => 'Editera: @titre@',
	'titre_page_articles_page' => 'Artiklar',
	'titre_page_articles_tous' => 'Hela sajten',
	'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Sajtens inställningar',
	'titre_page_delete_all' => 'total och oåterkallelig radering',
	'titre_page_recherche' => 'Sökresultat @recherche@',
	'titre_page_statistiques_referers' => 'Statistik (inkommande länkar)',
	'titre_page_upgrade' => 'Uppgradera SPIP',
	'titre_publication_articles_post_dates' => 'Tidsstyrd publicering av artiklar',
	'titre_reparation' => 'Reparera',
	'titre_suivi_petition' => 'Uppföljning av namninasamlingar',
	'trad_article_traduction' => 'Alla versioner av den här artikeln:',
	'trad_delier' => 'Sluta länka den här artikeln till dess översättningar', # MODIF
	'trad_lier' => 'Den här artikeln är en översättning av artikel nummer:',
	'trad_new' => 'Skriv en ny översättning av den här artikeln', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'Fel: teckenkodningen @charset@ stöds inte.',

	// V
	'version' => 'Version:'
);

?>
